#!$CLEARCASE/bin/ccperl.exe
# SetZCCEnvAttr.pl - Simple script to set CC UCM Project attribute
#
# Authors:  Steve Seifert
# Last updated:  Steve Seifert, 9/14/06
#                Jane Huang, 7/15/07
#
# (c) Copyright IBM Corp. 2008
#
# The common routines used in all the build scripts are contained in the 
# bccpbmod.pm module.
#
# Saves environment information in CC UCM Project attribute.
# Uses hardcoded values and hardcoded project names.
#
# This script can be modified to use as a trigger script and limited to
# specific users during development using the following lines and 
# changing the username strings.
# my $user = $ENV{'USERNAME'};
# exit 0 if ((lc $user ne "sseifert") && (lc $user ne "brandt\.onorato"));
#
# You must modify this script before attempting to use parameterized build.
# Sections that require modification and the instructions for modifying them
# are flagged with the following comment lines:
#
# ******************************************************************************
# * Customization instructions:                                                *
# * [instructions here]                                                        *
# ******************************************************************************

#use bccpbmod;

my $status = 0;

# *******************************************************************************
# * Required customization:                                                     *
# * The Project and life cycle information.                                     *
# *******************************************************************************
my $project 	= 'parmbld';   		# Project 
my $pvob 	= 'pvob_parmbld'; 	# PVOB
my $lifecycle   = 'DEV';                # lifecycle: PROD, DEV, QA
  
# *******************************************************************************
# * Optional customization:                                                     *
# * You can use the optional variables or add new variables based on your site's*
# * needs.  If you determine to use the optional variables or add new variables,*
# * you have to update all related scripts correspondently.                     *
# *******************************************************************************
my $value;  # $env, $db2sys, $menv, $os390_hostname, $os390_port, $stage
            # $copylib1, $copylib2, $copylib3, $copylib4;
            # $syslib1, $syslib2, $syslib3;
            # $syslib4, $steplib1, $steplib2;			 # Optional
            # $hostpds_prefix, $hostpds_affix, $cbllib;	         # Optional 
            # $loadlib, $c390llib, $dbrmlib, $tgtlib, $db2_owner

#################################################################################################
# Variable		Description		Required	 Example or Remarks 
# $project 		project name		Y		e.g. parmbld
# $pvob			PVOB name		Y		e.g. pvob_parmbld
# $env			Specified environment	Y		PROD, DEV, QA
# $db2sys		Specified DB2 				DB2
# $menv								n\a
# $os390_hostname	Remote Build Server  	Y		e.g. stplex4a.svl.ibm.com
# $os390_port		Port number to run RB 	Y		e.g. 9525, or 1-699999??/
# $stage							n\a
# $copylib1		Copybook library 	Y		Copybook library
# $copylib2		Copybook library			Based on site requirement 
# $copylib3		Copybook library			Based on site requirement
# $copylib4		Copybook library			Based on site requirement
# $syslib1		System library		Y		System library  
# $syslib2		System library 				Based on site requirement
# $syslib3		System library 				Based on site requirement
# $syslib4		System library 				Based on site requirement
# $steplib1		Step library				Based on site requirement
# $steplib2		Step library				Based on site requirement
# $hostpds_prefix	Form PDS name				Based on site requirement
# $hostpds_affix	Form PDS name 				Based on site requirement
# $cbllib		PDS - Checkin Cobol			Allocated PDS hold checkin Cobol file
# $loadlib		PDS - Load module  	Y		Allocated PDS for linking results
# $c390llib							n\a
# $dbrmlib		DB2 					n\a
# $tgtlib		PDS - Checkin copybook			Allocated PDS hold checkin copybook
# $db2_owner		DB2 					n\a

##################################################################################################
#$bccpbmod::debug = 1;

print " create project attribute for life cycle: $lifecycle !\n";

# *******************************************************************************
# * Required customization:                                                     *
# * The following environment variables are required to set up for the type     *
# * attribute ZCCENV.  Review the document for details.                         *
# *******************************************************************************

if ($lifecycle eq "DEV") {
#$value  = "\\\"$bccpbmod::DEV_env,DB2P,,stplex4a.svl.ibm.com,9525,.STAGE,";
$value  = "\\\"DEV,DB2,QA,stplex4a.svl.ibm.com,9525,,";
$value .= "JHUANG.B.COPYLIB,JHUANG.B.COPYLIB2,JHUANG.B.COPYLIB3,JHUANG.B.COPYLIB4,";
$value .= "JHUANG.C.SYSLIB,JHUANG.C.SYSLIB2,JHUANG.C.SYSLIB3,";
#$value .= "JHUANG.C.SYSLIB4,JHUANG.C.STEPLIB1,,";              # Optional
#$value .= ",A,JHUANG.CI.SOURCE,";     				# Optional 
$value .= "JHUANG.CA.PARMBLD.LOAD,IMS.PGMTEST,DB2.DBRM.TEST,JHUANG.CI.COPYLIB,MFX@\\\"";
} elsif ($lifecycle eq "PROD"){
$value  = "\\\"PROD,DB2,QA,stplex4a.svl.ibm.com,9525,,";
$value .= "JHUANG.P.COPYLIB,JHUANG.P.COPYLIB2,JHUANG.P.COPYLIB3,JHUANG.P.COPYLIB4,";
$value .= "JHUANG.P.SYSLIB,JHUANG.P.SYSLIB2,JHUANG.P.SYSLIB3,";
#$value .= "JHUANG.P.SYSLIB4,JHUANG.P.STEPLIB1,,";              # Optional
#$value .= ",A,JHUANG.PCI.SOURCE,";    				# Optional 
$value .= "JHUANG.PCA.PARMBLD.LOAD,IMS.PGMTESTP,DB2.DBRM.TESTP,JHUANG.PCI.COPYLIB,MFX@\\\"";
} elsif ($lifecycle eq "QA"){
$value  = "\\\"QA,DB2,QA,stplex4a.svl.ibm.com,9525,,";
$value .= "JHUANG.Q.COPYLIB,JHUANG.Q.COPYLIB2,JHUANG.Q.COPYLIB3,JHUANG.Q.COPYLIB4,";
$value .= "JHUANG.Q.SYSLIB,JHUANG.Q.SYSLIB2,JHUANG.Q.SYSLIB3,";
#$value .= "JHUANG.Q.SYSLIB4,JHUANG.Q.STEPLIB1,,";              # Optional
#$value .= ",A,JHUANG.QCI.SOURCE,";    				# Optional 
$value .= "JHUANG.QCA.PARMBLD.LOAD,IMS.PGMTESTQ,DB2.DBRM.TESTQ,JHUANG.QCI.COPYLIB,MFX@\\\"";
}else {
	printf "Please provide a valid life cycle !" ;
} 
# $status = `cleartool mkattr -replace -nc ZCCENV $value project:parmbld@\\pvob_parmbld`;
$status = `cleartool mkattr -replace -nc ZCCENV $value  project:$project@\\$pvob`;

print "Status: $status\n";


exit 0;
